@@ -42,7 +42,8 @@ corrected_tau <- function(data, dvar, pvar, mvar,
   
   # validity check ----
   check_args(
-    by_call(tau_method, "corrected_tau"),
+    
+    by_call(tau_method),
     within(alpha, 0, 1),
     is_logical(continuity),
     is_logical(repeated)
@@ -73,7 +74,7 @@ corrected_tau <- function(data, dvar, pvar, mvar,
       )
       auto_tau <- list(tau = NA, z = NA, p = NA)
     } else {
-      auto_tau <- .kendall_full(
+      auto_tau <- kendall_tau(
         A_data[[dvar]], 
         A_data[[mvar]], 
         continuity_correction = continuity,
@@ -86,12 +87,12 @@ corrected_tau <- function(data, dvar, pvar, mvar,
     data$fit <- predict(fit_mblm, data, se.fit = FALSE)
     x <- data[[dvar]] - data$fit
     y <- as.numeric(factor(data[[pvar]]))
-    base_corr_tau <- .kendall_full(
+    base_corr_tau <- kendall_tau(
       x, y, continuity_correction = continuity, tau_method = tau_method
     )
     
     x <- data[[dvar]]
-    uncorrected_tau <- .kendall_full(
+    uncorrected_tau <- kendall_tau(
       x, y, continuity_correction = continuity, tau_method = tau_method
     )
     
