@@ -60,6 +60,12 @@
 #'   phase_design = c(A = 5, B = 6), name = "Klaas"
 #' )
 #'
+#' # Alternative coding 3:
+#' klaas <- scdf(
+#'   c(5, 7, 8, 5, 7, 12, 16, 18, 15, 14, 19),
+#'   phase_starts = c(A = 1, B = 7), name = "Klaas"
+#' )
+#' 
 #' ## Unfortunately in a similar study there were no data collected on
 #' ## days 3 and 9. Use NA to pass them to the function:
 #' emmi <- scdf(c(5, 7, NA, 5, 7, 12, 16, 18, NA, 14, 19),
@@ -202,6 +208,14 @@ phase_starts2phase_design <- function(starts, mt) {
            "Measurement time does not exist.", call. = FALSE)
   })
   
+  if (ids[1] != mt[1]) {
+    stop("phase_starts not defined correctly. ", 
+         "First phase must start at the first measurement time which is ", 
+         mt[1], ".", 
+         call. = FALSE)
+  }
+    
+  
   phase_design <- list()
   for (i in 2:length(ids)) {
     phase_design[[names(starts)[i - 1]]] <- ids[[i]] - ids[[i - 1]]
